@@ -63,6 +63,6 @@ class FFile:
 			self.read_json()
 			list(self.json_[to_key]).append(content)
 			with open(self.nomeFile, "a") as fa:
-				fa.write(self.json_)
+				fa.write(json.dump(self.json_))
 		else:
 			self.create_file(json.dump(content))
\ No newline at end of file
